from flask import Flask, render_template, request
import os 

app = Flask(__name__)

app_title = os.getenv('APP_TITLE', 'JupyShare')


def get_breadcrumbs():
    path_parts = request.path.split('/')[1:]  # Remove empty first element
    breadcrumbs = []
    accumulated_path = ''
    
    for i, part in enumerate(path_parts):
        if not part:
            continue
        accumulated_path += f'/{part}'
        breadcrumbs.append({
            'name': part.capitalize(),
            'url': accumulated_path,
            'is_active': (i == len(path_parts) - 1)
        })
    
    # Always include home at the beginning
    if not breadcrumbs or breadcrumbs[0]['name'].lower() != 'home':
        breadcrumbs.insert(0, {
            'name': 'Home',
            'url': '/',
            'is_active': len(path_parts) == 0
        })
    
    return breadcrumbs

@app.route('/')
def home():
    print(get_breadcrumbs())
    return render_template('index.html', 
                            app_title=app_title,
                            breadcrumbs=get_breadcrumbs()
                           )

if __name__ == "__main__":
    app.run(debug=True)
